conformance

Function conformance 

pub fn conformance(
    layout: &Layout,
    item: usize,
    alphabetic: bool,
    decimal_point_comma: bool,
    formal: &Formal,
) -> Option<String>
Why argument item of the caller’s layout does not conform to formal. A literal or an expression has no description to conform: it is moved or computed into a temporary of the formal parameter’s (assumption C272).