pub struct Formal {
pub name: String,
pub by_value: bool,
pub kind: Kind,
pub size: u32,
pub scaling: u32,
pub alphabetic: bool,
pub edit: Option<(Vec<Sym>, String)>,
pub decimal_point_comma: bool,
}Expand description
A formal parameter or the RETURNING item: what an argument conforms to, and the shape of the temporary that holds a literal or expression argument.
Fields
name: Stringby_value: boolkind: Kindsize: u32scaling: u32alphabetic: booledit: Option<(Vec<Sym>, String)>An edited item’s PICTURE symbols and the currency string its currency symbol stands for.
decimal_point_comma: boolTrait Implementations
impl Eq for Formal
impl StructuralPartialEq for Formal